package com.perforce.hws;

import com.perforce.hws.core.HwsPluginLoader;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import ro.fortsoft.pf4j.DefaultPluginManager;
import ro.fortsoft.pf4j.PluginManager;
import spark.Service;

import java.io.File;
import java.io.IOException;
import java.util.List;

public class HwsPluginManager {

	private static Logger logger = LoggerFactory.getLogger(HwsPluginManager.class);

	private static HwsPluginManager instance = null;

	private PluginManager pluginManager;
	private List<HwsPluginLoader> loaders;

	/**
	 * Singleton - 'private' to prevent subclassing
	 */
	private HwsPluginManager() {
	}

	public static HwsPluginManager getInstance() {
		if(instance == null) {
			instance = new HwsPluginManager();
		}
		return instance;
	}

	public void loadPlugins() throws IOException {
		pluginManager = new DefaultPluginManager();
		pluginManager.loadPlugins();
		pluginManager.startPlugins();

		loaders = pluginManager.getExtensions(HwsPluginLoader.class);
	}

	public void loadPlugin(File pluginArchiveFile) throws IOException {
		pluginManager = new DefaultPluginManager();
		pluginManager.loadPlugin(pluginArchiveFile);
		pluginManager.startPlugins();

		loaders = pluginManager.getExtensions(HwsPluginLoader.class);
	}

	public void addRoutes(String basePath, Service service) {
		for (HwsPluginLoader l : loaders) {
			String plugin = l.getName();
			logger.info("Loading routes for " + plugin + ":");
			l.addRoutes(basePath, service);
		}
	}

}
