package com.perforce.hws.utils;

/**
 * Enum to help with the definition and building of REST paths.
 * 
 * All of our REST paths begin with a /api prefix followed by a
 * context which defines the responsibility for handling the
 * request and a version specifier for the api within this
 * context; currently there are HelixWebServices and Perforce
 * contexts.
 * 
 * Following the versioned context there are various fixed and 
 * dynamic components to a path which depend upon the operation 
 * being carried out.
 * 
 * Examples
 * --------
 * 
 * /api/hws/version       - get the current version of the hws api
 * /api/hws/v16.1/login   - login to hws using v16.1 of the api
 * /api/p4d/v16.1/localhost/branches - p4d branches in localhost
 */
public enum ApiPath {
	/** The generic '/api' path prefix. */
	Api("api"),
	/** The internal documentation. */
	Doc("doc/index.html"),
	/** The internal documentation directory. */
	DocDir("doc"),
	/** The Hws context. */
	Hws("hws"),
	/** The Login path, should be preceded by a context. */
	Login("login"),
	/** The P4d context. */
	P4d("p4d"),
	/** The Platform version. */
	PlatformVersion(":platformVersion"),
	/** The base path of the server. */
	Root(""),
	/** The Server id, available in request params. */
	Server(":server"),
	/** Route the request to a Perforce Server command processor. */
	Servers("servers"),
	/** The Status of this HelixWebService. */
	Status("status"),
	/** The Version of a particular api. */
	Version("version");
	
	/** The path. */
	private String path;
	
	/**
	 * Instantiates a new api path.
	 *
	 * @param thePath the the path
	 */
	ApiPath(final String thePath) {
		this.path = thePath;
	}

	public String getPath() {
		return path;
	}
}
